pub type Aliasers = AliasChildLocation;Expand description
We let locations alias into child locations of their own.
This is a very simple aliasing rule, mimicking the behaviour of
the DescendOrigin instruction.
Aliased Type
pub struct Aliasers;pub type Aliasers = AliasChildLocation;We let locations alias into child locations of their own.
This is a very simple aliasing rule, mimicking the behaviour of
the DescendOrigin instruction.
pub struct Aliasers;